==> factern-client-1.0.5.tar.gz: factern-client-1.0.5/factern_client/com/factern/model/field_store_values.py <==
#
# Template source downloaded from:
# https://github.com/swagger-api/swagger-codegen/tree/master/modules/swagger-codegen/src/main/resources/python
#
# coding: utf-8

"""
    Factern API
"""


import pprint
import re  # noqa: F401

import six


class FieldStoreValues(object):

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'str',
        'storage_id': 'str'
    }

    attribute_map = {
        'data': 'data',
        'storage_id': 'storageId'
    }

    def __init__(self, data=None, storage_id=None):  # noqa: E501
        """FieldStoreValues - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self._storage_id = None
        self.discriminator = None

        self.data = data
        if storage_id is not None:
            self.storage_id = storage_id

    @property
    def data(self):
        """Gets the data of this FieldStoreValues.  # noqa: E501


        :return: The data of this FieldStoreValues.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this FieldStoreValues.


        :param data: The data of this FieldStoreValues.  # noqa: E501
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def storage_id(self):
        """Gets the storage_id of this FieldStoreValues.  # noqa: E501


        :return: The storage_id of this FieldStoreValues.  # noqa: E501
        :rtype: str
        """
        return self._storage_id

    @storage_id.setter
    def storage_id(self, storage_id):
        """Sets the storage_id of this FieldStoreValues.


        :param storage_id: The storage_id of this FieldStoreValues.  # noqa: E501
        :type: str
        """

        self._storage_id = storage_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldStoreValues):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> factern-client-1.0.6.tar.gz: factern-client-1.0.6/factern_client/com/factern/model/field_store_values.py <==
# coding: utf-8

"""
    Factern API
"""


import pprint
import re  # noqa: F401

import six
import importlib




class FieldStoreValues():


    @staticmethod
    def compute_parent_updates():
        pass

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'str',
        'storage_id': 'str'
    }

    attribute_map = {
        'data': 'data',
        'storage_id': 'storageId'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """FieldStoreValues - a model defined in Swagger"""  # noqa: E501
        self.compute_parent_updates()
        for k in kwargs:
            if k not in self.swagger_types:
                raise ValueError("FieldStoreValues got unexpected argument '%s'" % k)

        self._data = None
        self._storage_id = None


        if "data" not in kwargs:
            raise ValueError("FieldStoreValues missing required argument: data")
        self._data = kwargs["data"]

        if "storage_id" in kwargs:
            self.storage_id = kwargs["storage_id"]

    @property
    def data(self):
        """Gets the data of this FieldStoreValues.  # noqa: E501


        :return: The data of this FieldStoreValues.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this FieldStoreValues.


        :param data: The data of this FieldStoreValues.  # noqa: E501
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    @property
    def storage_id(self):
        """Gets the storage_id of this FieldStoreValues.  # noqa: E501


        :return: The storage_id of this FieldStoreValues.  # noqa: E501
        :rtype: str
        """
        return self._storage_id

    @storage_id.setter
    def storage_id(self, storage_id):
        """Sets the storage_id of this FieldStoreValues.


        :param storage_id: The storage_id of this FieldStoreValues.  # noqa: E501
        :type: str
        """

        self._storage_id = storage_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldStoreValues):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
